"""Общая кодовая база для проектов БЦ Образование."""

#: Неопределенное значение.
#:
#: Может использоваться в т.ч. как значение аргументов по умолчанию, когда есть
#: необходимость отличать значение аргумента от ``None``.
Undefined = type('', (), {})
